==> wicketstuff-merged-resources-3.1.3-sources.jar: org/wicketstuff/mergedresources/versioning/IResourceVersionProvider.java <==
/**
 * Copyright 2010 Molindo GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wicketstuff.mergedresources.versioning;

public interface IResourceVersionProvider {

	/**
	 * @return AbstractResourceVersion for this resource, never null
	 * @throws VersionException
	 *             if version can't be determined
	 */
	AbstractResourceVersion getVersion(Class<?> scope, String file) throws VersionException;

	public static class VersionException extends Exception {

		public VersionException(final Class<?> scope, final String fileName, final String msg, final Throwable cause) {
			super(scope + ", " + fileName + ": " + msg, cause);
		}

		public VersionException(final Class<?> scope, final String fileName, final String msg) {
			super(scope + ", " + fileName + ": " + msg);
		}

		public VersionException(String msg) {
			super(msg);
		}

		public VersionException(String msg, Throwable cause) {
			super(msg, cause);
		}

		private static final long serialVersionUID = 1L;

	}
}

==> wicketstuff-merged-resources-4.0.1-sources.jar: org/wicketstuff/mergedresources/versioning/IResourceVersionProvider.java <==
/**
 * Copyright 2016 Molindo GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wicketstuff.mergedresources.versioning;

public interface IResourceVersionProvider {

	/**
	 * @return AbstractResourceVersion for this resource, never null
	 * @throws VersionException
	 *             if version can't be determined
	 */
	AbstractResourceVersion getVersion(Class<?> scope, String file) throws VersionException;

	public static class VersionException extends Exception {

		public VersionException(final Class<?> scope, final String fileName, final String msg, final Throwable cause) {
			super(scope + ", " + fileName + ": " + msg, cause);
		}

		public VersionException(final Class<?> scope, final String fileName, final String msg) {
			super(scope + ", " + fileName + ": " + msg);
		}

		public VersionException(final String msg) {
			super(msg);
		}

		public VersionException(final String msg, final Throwable cause) {
			super(msg, cause);
		}

		private static final long serialVersionUID = 1L;

	}
}
